%--------------------------------------------------------------------------
% File     : GRP039-6 : TPTP v2.6.0. Released v1.0.0.
% Domain   : Group Theory (Subgroups)
% Problem  : Subgroups of index 2 are normal
% Version  : [OTTER] axioms : Incomplete > Augmented > Incomplete.
% English  : If O is a subgroup of G and there are exactly 2 cosets 
%            in G/O, then O is normal [that is, for all x in G and 
%            y in O, x*y*inverse(x) is back in O].

% Refs     : 
% Source   : [OTTER]
% Names    : subgroup.in [OTTER]

% Status   : unsatisfiable
% Rating   : 0.38 v2.6.0, 0.33 v2.5.0, 0.20 v2.4.0, 0.00 v2.2.1, 0.50 v2.1.0, 0.62 v2.0.0
% Syntax   : Number of clauses    :   22 (   2 non-Horn;   9 unit;  14 RR)
%            Number of literals   :   48 (   0 equality)
%            Maximal clause size  :    4 (   2 average)
%            Number of predicates :    3 (   0 propositional; 1-3 arity)
%            Number of functors   :    7 (   5 constant; 0-2 arity)
%            Number of variables  :   48 (   0 singleton)
%            Maximal term depth   :    2 (   1 average)

% Comments : Used to define a subgroup of index two is a theorem which 
%            says that {for all x, for all y, there exists a z such that 
%            if x and y are both not in the subgroup O, then z is in O and 
%            x*z=y} if & only if {O has index 2 in G}. This z is named 
%            by the skolem function i(x,y). Explanation: If O is of index 
%            two in G, then there are exactly two cosets, namely O and 
%            uO for some u not in O. If both of x and y are not in O, then 
%            they are in uO. But then xO=yO, which implies that there 
%            exists some z in O such that x*z=y. If the condition holds 
%            that {for all x, for all y, there exists a z such that 
%            if x and y are both not in the subgroup O, then z is in O and 
%            x*z=y}, then xO=yO for all x,y not in O, which implies that 
%            there are at most two cosets; and there must be at least two, 
%            namely O and xO, since x is not in O. Therefore O must 
%            be of index two.
%          : element_in_O2(A,B) is A^-1.B. The axioms with element_in_O2 
%            force index 2.
%--------------------------------------------------------------------------
%----Only some of the axioms are supplied - included manually below 
% include('axioms/GRP003-0.ax').
% include('axioms/GRP003-0.eq').
%----Don't include sub-group theory axioms because equality is incomplete
%include('Axioms/GRP003-1.ax').
%include('Axioms/GRP003-1.eq').
%----Include equality axioms 
% include('axioms/equality.ax').
%--------------------------------------------------------------------------
input_clause(closure_of_inverse,axiom,
    [--subgroup_member(X),
     ++subgroup_member(inverse(X))]).

input_clause(closure_of_product,axiom,
    [--subgroup_member(A),
     --subgroup_member(B),
     --product(A,B,C),
     ++subgroup_member(C)]).

input_clause(subgroup_member_substitution,axiom,
    [--equalish(A,B),
     --subgroup_member(A),
     ++subgroup_member(B)]).

% input_clause(closure,axiom,
%     [++product(X,Y,multiply(X,Y))]).

input_clause(left_identity,axiom,
    [++product(identity,X,X)]).

input_clause(right_identity,axiom,
    [++product(X,identity,X)]).

input_clause(left_inverse,axiom,
    [++product(inverse(X),X,identity)]).

input_clause(right_inverse,axiom,
    [++product(X,inverse(X),identity)]).

input_clause(associativity1,axiom,
    [--product(X,Y,U),
     --product(Y,Z,V),
     --product(U,Z,W),
     ++product(X,V,W)]).

input_clause(associativity2,axiom,
    [--product(X,Y,U),
     --product(Y,Z,V),
     --product(X,V,W),
     ++product(U,Z,W)]).

input_clause(well_defined,axiom,
    [--product(X,Y,Z),
     --product(X,Y,W),
     ++equalish(Z,W)]).

% input_clause(inverse_substitution,axiom,
%     [--equalish(X,Y),
%      ++equalish(inverse(X),inverse(Y))]).

% input_clause(multiply_substitution1,axiom,
%     [--equalish(X,Y),
%      ++equalish(multiply(X,W),multiply(Y,W))]).

% input_clause(multiply_substitution2,axiom,
%     [--equalish(X,Y),
%      ++equalish(multiply(W,X),multiply(W,Y))]).

% input_clause(product_substitution1,axiom,
%     [--equalish(X,Y),
%      --product(X,W,Z),
%      ++product(Y,W,Z)]).

% input_clause(product_substitution2,axiom,
%     [--equalish(X,Y),
%      --product(W,X,Z),
%      ++product(W,Y,Z)]).

input_clause(product_substitution3,axiom,
    [--equalish(X,Y),
     --product(W,Z,X),
     ++product(W,Z,Y)]).

%----This axiom and the two cancellation lemmas are dependent 
input_clause(identity_is_in_subgroup,axiom,
    [++subgroup_member(identity)]).

input_clause(product_right_cancellation,axiom,
    [--product(A,B,C),
     --product(A,D,C),
     ++equalish(D,B)]).

input_clause(product_left_cancellation,axiom,
    [--product(A,B,C),
     --product(D,B,C),
     ++equalish(D,A)]).

%----Definition of subgroup of index 2 
input_clause(an_element_in_O2,axiom,
    [++subgroup_member(element_in_O2(A,B)),
     ++subgroup_member(B),
     ++subgroup_member(A)]).

input_clause(property_of_O2,axiom,
    [++product(A,element_in_O2(A,B),B),
     ++subgroup_member(B),
     ++subgroup_member(A)]).

%----Extra substitution axiom 
input_clause(element_in_O2_substitution1,axiom,
    [--equalish(A,B),
     ++equalish(element_in_O2(C,A),element_in_O2(C,B))]).

input_clause(element_in_O2_substitution2,axiom,
    [--equalish(A,B),
     ++equalish(element_in_O2(A,C),element_in_O2(B,C))]).

%----Denial of theorem 
input_clause(b_is_in_subgroup,conjecture,
    [++subgroup_member(b)]).

input_clause(b_times_a_inverse_is_c,conjecture,
    [++product(b,inverse(a),c)]).

input_clause(a_times_c_is_d,conjecture,
    [++product(a,c,d)]).

input_clause(prove_d_is_in_subgroup,conjecture,
    [--subgroup_member(d)]).
%--------------------------------------------------------------------------
