%--------------------------------------------------------------------------
% File     : MGT023+1 : TPTP v2.6.0. Released v2.0.0.
% Domain   : Management (Organisation Theory)
% Problem  : Stable environments have a critical point.
% Version  : [PB+94] axioms : Reduced & Augmented > Complete.
% English  : 

% Refs     : [PM93]  Peli & Masuch (1993), The Logic of Propogation Strateg
%          : [PM94]  Peli & Masuch (1994), The Logic of Propogation Strateg
%          : [Kam95] Kamps (1995), Email to G. Sutcliffe
% Source   : [Kam95]
% Names    : 

% Status   : theorem
% Rating   : 0.17 v2.6.0, 0.29 v2.5.0, 0.25 v2.4.0, 0.00 v2.1.0
% Syntax   : Number of formulae    :   19 (   1 unit)
%            Number of atoms       :   59 (  23 equality)
%            Maximal formula depth :    9 (   4 average)
%            Number of connectives :   42 (   2 ~  ;   0  |;  20  &)
%                                         (   0 <=>;  20 =>;   0 <=)
%                                         (   0 <~>;   0 ~|;   0 ~&)
%            Number of predicates  :    6 (   0 propositional; 1-4 arity)
%            Number of functors    :    4 (   2 constant; 0-2 arity)
%            Number of variables   :   57 (   0 singleton;  56 !;   1 ?)
%            Maximal term depth    :    2 (   1 average)

% Comments : 
%--------------------------------------------------------------------------
%----Include equality axioms
include('Axioms/EQU001+0.ax').
%--------------------------------------------------------------------------
%----Subsitution axioms
input_formula(critical_point_substitution_1,axiom,(
    ! [A,B] : 
      ( equal(A,B)
     => equal(critical_point(A),critical_point(B)) )   )).

input_formula(growth_rate_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(growth_rate(A,C),growth_rate(B,C)) )   )).

input_formula(growth_rate_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(growth_rate(C,A),growth_rate(C,B)) )   )).

input_formula(environment_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & environment(A) )
     => environment(B) )   )).

input_formula(greater_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater(A,C) )
     => greater(B,C) )   )).

input_formula(greater_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater(C,A) )
     => greater(C,B) )   )).

input_formula(in_environment_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & in_environment(A,C) )
     => in_environment(B,C) )   )).

input_formula(in_environment_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & in_environment(C,A) )
     => in_environment(C,B) )   )).

input_formula(stable_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & stable(A) )
     => stable(B) )   )).

input_formula(subpopulations_substitution_1,axiom,(
    ! [A,B,C,D,E] : 
      ( ( equal(A,B)
        & subpopulations(A,C,D,E) )
     => subpopulations(B,C,D,E) )   )).

input_formula(subpopulations_substitution_2,axiom,(
    ! [A,B,C,D,E] : 
      ( ( equal(A,B)
        & subpopulations(C,A,D,E) )
     => subpopulations(C,B,D,E) )   )).

input_formula(subpopulations_substitution_3,axiom,(
    ! [A,B,C,D,E] : 
      ( ( equal(A,B)
        & subpopulations(C,D,A,E) )
     => subpopulations(C,D,B,E) )   )).

input_formula(subpopulations_substitution_4,axiom,(
    ! [A,B,C,D,E] : 
      ( ( equal(A,B)
        & subpopulations(C,D,E,A) )
     => subpopulations(C,D,E,B) )   )).

%----Problem axioms
%----D1=>. A time point is the critical point of an environmental patch,
%----if and only if, it is the earliest time past which the growth rate of
%----efficient producers permanently exceeds growth rate of first movers.
input_formula(d1,hypothesis,(
    ! [E,To] : 
      ( ( environment(E)
        & ~ greater(growth_rate(efficient_producers,To),
growth_rate(first_movers,To))
        & in_environment(E,To)
        & ! [T] : 
            ( ( subpopulations(first_movers,efficient_producers,E,T)
              & greater(T,To) )
           => greater(growth_rate(efficient_producers,T),
growth_rate(first_movers,T)) ) )
     => equal(To,critical_point(E)) )   )).

%----L12. There is an earliest time point, past which FM's growth rate
%----exceeds EP's growth rate.
input_formula(l12,hypothesis,(
    ! [E] : 
      ( ( environment(E)
        & stable(E) )
     => ? [To] : 
          ( in_environment(E,To)
          & ~ greater(growth_rate(efficient_producers,To),
growth_rate(first_movers,To))
          & ! [T] : 
              ( ( subpopulations(first_movers,efficient_producers,E,T)
                & greater(T,To) )
             => greater(growth_rate(efficient_producers,T),
growth_rate(first_movers,T)) ) ) )   )).

%----GOAL: L5. Stable environments have a critical point.
input_formula(prove_l5,conjecture,(
    ! [E] : 
      ( ( environment(E)
        & stable(E) )
     => in_environment(E,critical_point(E)) )   )).
%--------------------------------------------------------------------------
