%--------------------------------------------------------------------------
% File     : MGT031+1 : TPTP v2.6.0. Released v2.0.0.
% Domain   : Management (Organisation Theory)
% Problem  : First movers appear first in an environment
% Version  : [PB+94] axioms : Reduced & Augmented > Complete.
% English  : 

% Refs     : [PM93]  Peli & Masuch (1993), The Logic of Propogation Strateg
%          : [PM94]  Peli & Masuch (1994), The Logic of Propogation Strateg
%          : [Kam95] Kamps (1995), Email to G. Sutcliffe
% Source   : [Kam95]
% Names    : 

% Status   : satisfiable
% Rating   : 0.00 v2.1.0
% Syntax   : Number of formulae    :   29 (   1 unit)
%            Number of atoms       :   80 (  32 equality)
%            Maximal formula depth :    5 (   3 average)
%            Number of connectives :   53 (   2 ~  ;   2  |;  21  &)
%                                         (   1 <=>;  27 =>;   0 <=)
%                                         (   0 <~>;   0 ~|;   0 ~&)
%            Number of predicates  :    6 (   0 propositional; 1-3 arity)
%            Number of functors    :    8 (   5 constant; 0-2 arity)
%            Number of variables   :   75 (   0 singleton;  74 !;   1 ?)
%            Maximal term depth    :    3 (   1 average)

% Comments : 
%--------------------------------------------------------------------------
%----Include equality axioms
include('Axioms/EQU001+0.ax').
%--------------------------------------------------------------------------
%----Subsitution axioms
input_formula(appear_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(appear(A,C),appear(B,C)) )   )).

input_formula(appear_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(appear(C,A),appear(C,B)) )   )).

input_formula(cardinality_at_time_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(cardinality_at_time(A,C),cardinality_at_time(B,C)) )   )).

input_formula(cardinality_at_time_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(cardinality_at_time(C,A),cardinality_at_time(C,B)) )   )).

input_formula(number_of_organizations_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(number_of_organizations(A,C),
number_of_organizations(B,C)) )   )).

input_formula(number_of_organizations_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(number_of_organizations(C,A),
number_of_organizations(C,B)) )   )).

input_formula(environment_substitution_1,axiom,(
    ! [A,B] : 
      ( ( equal(A,B)
        & environment(A) )
     => environment(B) )   )).

input_formula(greater_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater(A,C) )
     => greater(B,C) )   )).

input_formula(greater_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater(C,A) )
     => greater(C,B) )   )).

input_formula(greater_or_equal_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater_or_equal(A,C) )
     => greater_or_equal(B,C) )   )).

input_formula(greater_or_equal_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & greater_or_equal(C,A) )
     => greater_or_equal(C,B) )   )).

input_formula(in_environment_substitution_1,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & in_environment(A,C) )
     => in_environment(B,C) )   )).

input_formula(in_environment_substitution_2,axiom,(
    ! [A,B,C] : 
      ( ( equal(A,B)
        & in_environment(C,A) )
     => in_environment(C,B) )   )).

input_formula(subpopulation_substitution_1,axiom,(
    ! [A,B,C,D] : 
      ( ( equal(A,B)
        & subpopulation(A,C,D) )
     => subpopulation(B,C,D) )   )).

input_formula(subpopulation_substitution_2,axiom,(
    ! [A,B,C,D] : 
      ( ( equal(A,B)
        & subpopulation(C,A,D) )
     => subpopulation(C,B,D) )   )).

input_formula(subpopulation_substitution_3,axiom,(
    ! [A,B,C,D] : 
      ( ( equal(A,B)
        & subpopulation(C,D,A) )
     => subpopulation(C,D,B) )   )).

%----Problem axioms
%----MP. The number of organizations is positive in the environment when
%----they appear in this environment.
input_formula(mp_positive_number_when_appear,axiom,(
    ! [E] : 
      ( environment(E)
     => greater(number_of_organizations(e,appear(an_organisation,E)),
zero) )   )).

%----MP. If the number of organizations is positive in the environment,
%----then there is a non-empty subpopulation in the environment.
input_formula(mp_number_mean_non_empty,axiom,(
    ! [E,T] : 
      ( ( environment(E)
        & greater(number_of_organizations(E,T),zero) )
     => ? [S] : 
          ( subpopulation(S,E,T)
          & greater(cardinality_at_time(S,T),zero) ) )   )).

%----MP. There are no EP in the environment before their appearence.
input_formula(mp_no_EP_before_appearance,axiom,(
    ! [E,T] : 
      ( ( environment(E)
        & in_environment(E,T)
        & greater(appear(efficient_producers,E),T) )
     => ~ greater(cardinality_at_time(efficient_producers,T),zero) )   )).

%----MP. There are no FM in the environment before their appearence.
input_formula(mp_no_FM_before_appearance,axiom,(
    ! [E,T] : 
      ( ( environment(E)
        & in_environment(E,T)
        & greater(appear(first_movers,E),T) )
     => ~ greater(cardinality_at_time(first_movers,T),zero) )   )).

%----MP. The appearence of FM cannot precede the appearence of the first
%----organization in the environment.
input_formula(mp_FM_not_precede_first,axiom,(
    ! [E] : 
      ( environment(E)
     => greater_or_equal(appear(first_movers,E),appear(an_organisation,
E)) )   )).

%----MP. inequality
input_formula(mp_greater_transitivity,axiom,(
    ! [X,Y,Z] : 
      ( ( greater(X,Y)
        & greater(Y,Z) )
     => greater(X,Z) )   )).

%----MP. on "greater or equal to"
input_formula(mp_greater_or_equal,axiom,(
    ! [X,Y] : 
      ( greater_or_equal(X,Y)
    <=> ( greater(X,Y)
        | equal(X,Y) ) )   )).

%----A9. The population contains only first movers and efficient
%----producers.
input_formula(a9,hypothesis,(
    ! [E,X,T] : 
      ( ( environment(E)
        & subpopulation(X,E,T)
        & greater(cardinality_at_time(X,T),zero) )
     => ( equal(X,efficient_producers)
        | equal(X,first_movers) ) )   )).

%----A13. First movers appear sooner in the environment, than efficient
%----producers.
input_formula(a13,hypothesis,(
    ! [E] : 
      ( environment(E)
     => greater(appear(efficient_producers,e),appear(first_movers,E)) )   )).

%----GOAL:L13. First movers are the first organizations that appear in the
%----environment.
input_formula(prove_l13,conjecture,(
    ! [E] : 
      ( ( environment(E)
        & in_environment(E,appear(an_organisation,E)) )
     => equal(appear(an_organisation,E),appear(first_movers,E)) )   )).
%--------------------------------------------------------------------------
