%--------------------------------------------------------------------------
% File     : MGT042-1 : TPTP v2.6.0. Released v2.4.0.
% Domain   : Management (Organisation Theory)
% Problem  : Conditions for a lower hazard of mortality
% Version  : [Han98] axioms.
% English  : When an organization lacks immunity, increased collective
%            knowledge and superior external ties lower its hazard of
%            mortality when internal friction does not increase.

% Refs     : [Kam00] Kamps (2000), Email to G. Sutcliffe
%            [CH00]  Carroll & Hannan (2000), The Demography of Corporation
%            [Han98] Hannan (1998), Rethinking Age Dependence in Organizati
% Source   : [TPTP]
% Names    : 

% Status   : unsatisfiable
% Rating   : 0.50 v2.6.0, 0.56 v2.5.0, 0.67 v2.4.0
% Syntax   : Number of clauses    :   64 (  15 non-Horn;   4 unit;  50 RR)
%            Number of literals   :  160 (  54 equality)
%            Maximal clause size  :    6 (   2 average)
%            Number of predicates :    7 (   0 propositional; 1-2 arity)
%            Number of functors   :    9 (   3 constant; 0-2 arity)
%            Number of variables  :  121 (   0 singleton)
%            Maximal term depth   :    2 (   1 average)

% Comments : The original text uses mnemonic names:
%            Original:    C/F/P:  Arity:    New name:
%            zero-symbol  c       0         zero
%            eta-symbol   c       0         eta
%            sigma-symbol c       0         sigma
%            tau-symbol   c       0         tau
%            very_low     c       0         very_low
%            low          c       0         low
%            mod1         c       0         mod1
%            mod2         c       0         mod2
%            high         c       0         high
%            A            f       2         age  
%            H            f       2         hazard_of_mortality  
%            C            f       2         capability  
%            P            f       2         position  
%            K            f       2         stock_of_knowledge  
%            T            f       2         external_ties  
%            F            f       2         internal_friction  
%            O            p       1         organization  
%            EN           p       1         has_endowment  
%            IM           p       2         has_immunity  
%            DS           p       3         dissimilar  
%            AL           p       2         is_aligned  
%            PA           p       2         positional_advantage  
%            FG           p       1         fragile_position  
%            RB           p       1         robust_position  
%          : Created with tptp2X -f tptp -t clausify:otter MGT042+1.p 
%--------------------------------------------------------------------------
%----Include equality axioms
include('Axioms/EQU001-0.ax').
%----Include inequality axioms
include('Axioms/MGT001-0.ax').
include('Axioms/MGT001-0.eq').
%--------------------------------------------------------------------------
input_clause(capability_substitution_1_23,axiom,
    [--equal(A,B),
     ++equal(capability(A,C),capability(B,C))]).

input_clause(capability_substitution_2_24,axiom,
    [--equal(A,B),
     ++equal(capability(C,A),capability(C,B))]).

input_clause(external_ties_substitution_1_25,axiom,
    [--equal(A,B),
     ++equal(external_ties(A,C),external_ties(B,C))]).

input_clause(external_ties_substitution_2_26,axiom,
    [--equal(A,B),
     ++equal(external_ties(C,A),external_ties(C,B))]).

input_clause(hazard_of_mortality_substitution_1_27,axiom,
    [--equal(A,B),
     ++equal(hazard_of_mortality(A,C),hazard_of_mortality(B,C))]).

input_clause(hazard_of_mortality_substitution_2_28,axiom,
    [--equal(A,B),
     ++equal(hazard_of_mortality(C,A),hazard_of_mortality(C,B))]).

input_clause(internal_friction_substitution_1_29,axiom,
    [--equal(A,B),
     ++equal(internal_friction(A,C),internal_friction(B,C))]).

input_clause(internal_friction_substitution_2_30,axiom,
    [--equal(A,B),
     ++equal(internal_friction(C,A),internal_friction(C,B))]).

input_clause(position_substitution_1_31,axiom,
    [--equal(A,B),
     ++equal(position(A,C),position(B,C))]).

input_clause(position_substitution_2_32,axiom,
    [--equal(A,B),
     ++equal(position(C,A),position(C,B))]).

input_clause(stock_of_knowledge_substitution_1_33,axiom,
    [--equal(A,B),
     ++equal(stock_of_knowledge(A,C),stock_of_knowledge(B,C))]).

input_clause(stock_of_knowledge_substitution_2_34,axiom,
    [--equal(A,B),
     ++equal(stock_of_knowledge(C,A),stock_of_knowledge(C,B))]).

input_clause(has_immunity_substitution_1_35,axiom,
    [--equal(A,B),
     --has_immunity(A,C),
     ++has_immunity(B,C)]).

input_clause(has_immunity_substitution_2_36,axiom,
    [--equal(A,B),
     --has_immunity(C,A),
     ++has_immunity(C,B)]).

input_clause(organization_substitution_1_37,axiom,
    [--equal(A,B),
     --organization(A),
     ++organization(B)]).

input_clause(assumption_4_38,axiom,
    [--organization(A),
     ++has_immunity(A,B),
     ++has_immunity(A,C),
     --greater(capability(A,C),capability(A,B)),
     --greater_or_equal(position(A,C),position(A,B)),
     ++smaller(hazard_of_mortality(A,C),hazard_of_mortality(A,B))]).

input_clause(assumption_4_39,axiom,
    [--organization(A),
     ++has_immunity(A,B),
     ++has_immunity(A,C),
     --greater_or_equal(capability(A,C),capability(A,B)),
     --greater(position(A,C),position(A,B)),
     ++smaller(hazard_of_mortality(A,C),hazard_of_mortality(A,B))]).

input_clause(assumption_4_40,axiom,
    [--organization(A),
     ++has_immunity(A,B),
     ++has_immunity(A,C),
     --equal(capability(A,C),capability(A,B)),
     --equal(position(A,C),position(A,B)),
     ++equal(hazard_of_mortality(A,C),hazard_of_mortality(A,B))]).

input_clause(assumption_5_41,axiom,
    [--organization(A),
     --greater(stock_of_knowledge(A,B),stock_of_knowledge(A,C)),
     --smaller_or_equal(internal_friction(A,B),internal_friction(A,C)),
     ++greater(capability(A,B),capability(A,C))]).

input_clause(assumption_5_42,axiom,
    [--organization(A),
     --smaller_or_equal(stock_of_knowledge(A,B),stock_of_knowledge(A,C)),
     --greater(internal_friction(A,B),internal_friction(A,C)),
     ++smaller(capability(A,B),capability(A,C))]).

input_clause(assumption_5_43,axiom,
    [--organization(A),
     --equal(stock_of_knowledge(A,B),stock_of_knowledge(A,C)),
     --equal(internal_friction(A,B),internal_friction(A,C)),
     ++equal(capability(A,B),capability(A,C))]).

input_clause(assumption_6_44,axiom,
    [--organization(A),
     --greater(external_ties(A,B),external_ties(A,C)),
     ++greater(position(A,B),position(A,C))]).

input_clause(assumption_6_45,axiom,
    [--organization(A),
     --equal(external_ties(A,B),external_ties(A,C)),
     ++equal(position(A,B),position(A,C))]).

input_clause(lemma_1_46,conjecture,
    [++organization(sk1)]).

input_clause(lemma_1_47,conjecture,
    [--has_immunity(sk1,sk2)]).

input_clause(lemma_1_48,conjecture,
    [--has_immunity(sk1,sk3)]).

input_clause(lemma_1_49,conjecture,
    [++greater(stock_of_knowledge(sk1,sk3),stock_of_knowledge(sk1,sk2)),
     ++greater_or_equal(stock_of_knowledge(sk1,sk3),stock_of_knowledge(sk1,sk2))]).

input_clause(lemma_1_50,conjecture,
    [++greater(stock_of_knowledge(sk1,sk3),stock_of_knowledge(sk1,sk2)),
     ++smaller_or_equal(internal_friction(sk1,sk3),internal_friction(sk1,sk2))]).

input_clause(lemma_1_51,conjecture,
    [++greater(stock_of_knowledge(sk1,sk3),stock_of_knowledge(sk1,sk2)),
     ++greater(external_ties(sk1,sk3),external_ties(sk1,sk2))]).

input_clause(lemma_1_52,conjecture,
    [++smaller_or_equal(internal_friction(sk1,sk3),internal_friction(sk1,sk2)),
     ++greater_or_equal(stock_of_knowledge(sk1,sk3),stock_of_knowledge(sk1,sk2))]).

input_clause(lemma_1_53,conjecture,
    [++greater_or_equal(external_ties(sk1,sk3),external_ties(sk1,sk2)),
     ++greater_or_equal(stock_of_knowledge(sk1,sk3),stock_of_knowledge(sk1,sk2))]).

input_clause(lemma_1_54,conjecture,
    [++smaller_or_equal(internal_friction(sk1,sk3),internal_friction(sk1,sk2)),
     ++smaller_or_equal(internal_friction(sk1,sk3),internal_friction(sk1,sk2))]).

input_clause(lemma_1_55,conjecture,
    [++smaller_or_equal(internal_friction(sk1,sk3),internal_friction(sk1,sk2)),
     ++greater(external_ties(sk1,sk3),external_ties(sk1,sk2))]).

input_clause(lemma_1_56,conjecture,
    [++greater_or_equal(external_ties(sk1,sk3),external_ties(sk1,sk2)),
     ++smaller_or_equal(internal_friction(sk1,sk3),internal_friction(sk1,sk2))]).

input_clause(lemma_1_57,conjecture,
    [++greater_or_equal(external_ties(sk1,sk3),external_ties(sk1,sk2)),
     ++greater(external_ties(sk1,sk3),external_ties(sk1,sk2))]).

input_clause(lemma_1_58,conjecture,
    [++greater(stock_of_knowledge(sk1,sk3),stock_of_knowledge(sk1,sk2)),
     --smaller(hazard_of_mortality(sk1,sk3),hazard_of_mortality(sk1,sk2))]).

input_clause(lemma_1_59,conjecture,
    [++smaller_or_equal(internal_friction(sk1,sk3),internal_friction(sk1,sk2)),
     --smaller(hazard_of_mortality(sk1,sk3),hazard_of_mortality(sk1,sk2))]).

input_clause(lemma_1_60,conjecture,
    [++greater_or_equal(external_ties(sk1,sk3),external_ties(sk1,sk2)),
     --smaller(hazard_of_mortality(sk1,sk3),hazard_of_mortality(sk1,sk2))]).

input_clause(lemma_1_61,conjecture,
    [--smaller(hazard_of_mortality(sk1,sk3),hazard_of_mortality(sk1,sk2)),
     ++greater_or_equal(stock_of_knowledge(sk1,sk3),stock_of_knowledge(sk1,sk2))]).

input_clause(lemma_1_62,conjecture,
    [--smaller(hazard_of_mortality(sk1,sk3),hazard_of_mortality(sk1,sk2)),
     ++smaller_or_equal(internal_friction(sk1,sk3),internal_friction(sk1,sk2))]).

input_clause(lemma_1_63,conjecture,
    [--smaller(hazard_of_mortality(sk1,sk3),hazard_of_mortality(sk1,sk2)),
     ++greater(external_ties(sk1,sk3),external_ties(sk1,sk2))]).

input_clause(lemma_1_64,conjecture,
    [--smaller(hazard_of_mortality(sk1,sk3),hazard_of_mortality(sk1,sk2)),
     --smaller(hazard_of_mortality(sk1,sk3),hazard_of_mortality(sk1,sk2))]).
%--------------------------------------------------------------------------
