%--------------------------------------------------------------------------
% File     : MGT051-1 : TPTP v2.6.0. Released v2.4.0.
% Domain   : Management (Organisation Theory)
% Problem  : Conditions for constant then increasing hazard of mortality
% Version  : [Han98] axioms.
% English  : An endowed organization's hazard of mortality remains constant 
%            during the period of immunity and increases monotonically with 
%            age once immunity ends.

% Refs     : [Kam00] Kamps (2000), Email to G. Sutcliffe
%            [CH00]  Carroll & Hannan (2000), The Demography of Corporation
%            [Han98] Hannan (1998), Rethinking Age Dependence in Organizati
% Source   : [TPTP]
% Names    : 

% Status   : unsatisfiable
% Rating   : 0.33 v2.6.0, 0.56 v2.5.0, 0.67 v2.4.0
% Syntax   : Number of clauses    :   67 (  11 non-Horn;   7 unit;  48 RR)
%            Number of literals   :  180 (  63 equality)
%            Maximal clause size  :    6 (   2 average)
%            Number of predicates :    8 (   0 propositional; 1-2 arity)
%            Number of functors   :   14 (   6 constant; 0-2 arity)
%            Number of variables  :  153 (   4 singleton)
%            Maximal term depth   :    3 (   1 average)

% Comments : See MGT042+1.p for the mnemonic names.
%          : Created with tptp2X -f tptp -t clausify:otter MGT051+1.p 
%--------------------------------------------------------------------------
%----Include equality axioms
include('Axioms/EQU001-0.ax').
%----Include inequality axioms
include('Axioms/MGT001-0.ax').
include('Axioms/MGT001-0.eq').
%--------------------------------------------------------------------------
input_clause(age_substitution_1_23,axiom,
    [--equal(A,B),
     ++equal(age(A,C),age(B,C))]).

input_clause(age_substitution_2_24,axiom,
    [--equal(A,B),
     ++equal(age(C,A),age(C,B))]).

input_clause(capability_substitution_1_25,axiom,
    [--equal(A,B),
     ++equal(capability(A,C),capability(B,C))]).

input_clause(capability_substitution_2_26,axiom,
    [--equal(A,B),
     ++equal(capability(C,A),capability(C,B))]).

input_clause(external_ties_substitution_1_27,axiom,
    [--equal(A,B),
     ++equal(external_ties(A,C),external_ties(B,C))]).

input_clause(external_ties_substitution_2_28,axiom,
    [--equal(A,B),
     ++equal(external_ties(C,A),external_ties(C,B))]).

input_clause(hazard_of_mortality_substitution_1_29,axiom,
    [--equal(A,B),
     ++equal(hazard_of_mortality(A,C),hazard_of_mortality(B,C))]).

input_clause(hazard_of_mortality_substitution_2_30,axiom,
    [--equal(A,B),
     ++equal(hazard_of_mortality(C,A),hazard_of_mortality(C,B))]).

input_clause(internal_friction_substitution_1_31,axiom,
    [--equal(A,B),
     ++equal(internal_friction(A,C),internal_friction(B,C))]).

input_clause(internal_friction_substitution_2_32,axiom,
    [--equal(A,B),
     ++equal(internal_friction(C,A),internal_friction(C,B))]).

input_clause(position_substitution_1_33,axiom,
    [--equal(A,B),
     ++equal(position(A,C),position(B,C))]).

input_clause(position_substitution_2_34,axiom,
    [--equal(A,B),
     ++equal(position(C,A),position(C,B))]).

input_clause(stock_of_knowledge_substitution_1_35,axiom,
    [--equal(A,B),
     ++equal(stock_of_knowledge(A,C),stock_of_knowledge(B,C))]).

input_clause(stock_of_knowledge_substitution_2_36,axiom,
    [--equal(A,B),
     ++equal(stock_of_knowledge(C,A),stock_of_knowledge(C,B))]).

input_clause(has_endowment_substitution_1_37,axiom,
    [--equal(A,B),
     --has_endowment(A),
     ++has_endowment(B)]).

input_clause(has_immunity_substitution_1_38,axiom,
    [--equal(A,B),
     --has_immunity(A,C),
     ++has_immunity(B,C)]).

input_clause(has_immunity_substitution_2_39,axiom,
    [--equal(A,B),
     --has_immunity(C,A),
     ++has_immunity(C,B)]).

input_clause(organization_substitution_1_40,axiom,
    [--equal(A,B),
     --organization(A),
     ++organization(B)]).

input_clause(definition_1_41,axiom,
    [--has_endowment(A),
     ++organization(A)]).

input_clause(definition_1_42,axiom,
    [--has_endowment(A),
     --smaller_or_equal(age(A,B),eta),
     ++has_immunity(A,B)]).

input_clause(definition_1_43,axiom,
    [--has_endowment(A),
     --greater(age(A,B),eta),
     --has_immunity(A,B)]).

input_clause(definition_1_44,axiom,
    [--organization(A),
     ++smaller_or_equal(age(A,sk1(A)),eta),
     ++greater(age(A,sk1(A)),eta),
     ++has_endowment(A)]).

input_clause(definition_1_45,axiom,
    [--organization(A),
     ++smaller_or_equal(age(A,sk1(A)),eta),
     ++has_immunity(A,sk1(A)),
     ++has_endowment(A)]).

input_clause(definition_1_46,axiom,
    [--organization(A),
     --has_immunity(A,sk1(A)),
     ++greater(age(A,sk1(A)),eta),
     ++has_endowment(A)]).

input_clause(definition_1_47,axiom,
    [--organization(A),
     --has_immunity(A,sk1(A)),
     ++has_immunity(A,sk1(A)),
     ++has_endowment(A)]).

input_clause(assumption_2_48,axiom,
    [--organization(A),
     --has_immunity(A,B),
     --has_immunity(A,C),
     ++equal(hazard_of_mortality(A,B),hazard_of_mortality(A,C))]).

input_clause(assumption_3_49,axiom,
    [--organization(A),
     --has_immunity(A,B),
     ++has_immunity(A,C),
     ++greater(hazard_of_mortality(A,C),hazard_of_mortality(A,B))]).

input_clause(assumption_4_50,axiom,
    [--organization(A),
     ++has_immunity(A,B),
     ++has_immunity(A,C),
     --greater(capability(A,C),capability(A,B)),
     --greater_or_equal(position(A,C),position(A,B)),
     ++smaller(hazard_of_mortality(A,C),hazard_of_mortality(A,B))]).

input_clause(assumption_4_51,axiom,
    [--organization(A),
     ++has_immunity(A,B),
     ++has_immunity(A,C),
     --greater_or_equal(capability(A,C),capability(A,B)),
     --greater(position(A,C),position(A,B)),
     ++smaller(hazard_of_mortality(A,C),hazard_of_mortality(A,B))]).

input_clause(assumption_4_52,axiom,
    [--organization(A),
     ++has_immunity(A,B),
     ++has_immunity(A,C),
     --equal(capability(A,C),capability(A,B)),
     --equal(position(A,C),position(A,B)),
     ++equal(hazard_of_mortality(A,C),hazard_of_mortality(A,B))]).

input_clause(assumption_5_53,axiom,
    [--organization(A),
     --greater(stock_of_knowledge(A,B),stock_of_knowledge(A,C)),
     --smaller_or_equal(internal_friction(A,B),internal_friction(A,C)),
     ++greater(capability(A,B),capability(A,C))]).

input_clause(assumption_5_54,axiom,
    [--organization(A),
     --smaller_or_equal(stock_of_knowledge(A,B),stock_of_knowledge(A,C)),
     --greater(internal_friction(A,B),internal_friction(A,C)),
     ++smaller(capability(A,B),capability(A,C))]).

input_clause(assumption_5_55,axiom,
    [--organization(A),
     --equal(stock_of_knowledge(A,B),stock_of_knowledge(A,C)),
     --equal(internal_friction(A,B),internal_friction(A,C)),
     ++equal(capability(A,B),capability(A,C))]).

input_clause(assumption_6_56,axiom,
    [--organization(A),
     --greater(external_ties(A,B),external_ties(A,C)),
     ++greater(position(A,B),position(A,C))]).

input_clause(assumption_6_57,axiom,
    [--organization(A),
     --equal(external_ties(A,B),external_ties(A,C)),
     ++equal(position(A,B),position(A,C))]).

input_clause(assumption_10_58,axiom,
    [--organization(A),
     ++equal(stock_of_knowledge(A,B),stock_of_knowledge(A,C))]).

input_clause(assumption_11_59,axiom,
    [--organization(A),
     ++equal(external_ties(A,B),external_ties(A,C))]).

input_clause(assumption_12_60,axiom,
    [--organization(A),
     --greater(age(A,B),age(A,C)),
     ++greater(internal_friction(A,B),internal_friction(A,C))]).

input_clause(theorem_4_61,conjecture,
    [++organization(sk2)]).

input_clause(theorem_4_62,conjecture,
    [++has_endowment(sk2)]).

input_clause(theorem_4_63,conjecture,
    [++smaller_or_equal(age(sk2,sk3),age(sk2,sk4))]).

input_clause(theorem_4_64,conjecture,
    [++smaller_or_equal(age(sk2,sk4),eta)]).

input_clause(theorem_4_65,conjecture,
    [++greater(age(sk2,sk5),eta)]).

input_clause(theorem_4_66,conjecture,
    [++greater(age(sk2,sk6),age(sk2,sk5))]).

input_clause(theorem_4_67,conjecture,
    [--greater(hazard_of_mortality(sk2,sk6),hazard_of_mortality(sk2,sk5)),
     --greater(hazard_of_mortality(sk2,sk5),hazard_of_mortality(sk2,sk4)),
     --equal(hazard_of_mortality(sk2,sk4),hazard_of_mortality(sk2,sk3))]).
%--------------------------------------------------------------------------
