%--------------------------------------------------------------------------
% File     : MGT056+1 : TPTP v2.6.0. Released v2.4.0.
% Domain   : Management (Organisation Theory)
% Problem  : Conditions for a constant then jumping hazard of mortality 2
% Version  : [Han98] axioms.
% English  : When (`eta' >= `sigma') in a drifting environment, an endowed
%            organization's hazard of mortality remains constant until age
%            `eta' and then jumps to a higher level in a drifting environment.

% Refs     : [Kam00] Kamps (2000), Email to G. Sutcliffe
%            [CH00]  Carroll & Hannan (2000), The Demography of Corporation
%            [Han98] Hannan (1998), Rethinking Age Dependence in Organizati
% Source   : [Kam00]
% Names    : LEMMA 9 [Han98]

% Status   : theorem
% Rating   : 0.17 v2.6.0, 0.33 v2.5.0, 0.17 v2.4.0
% Syntax   : Number of formulae    :   29 (   1 unit)
%            Number of atoms       :   89 (  32 equality)
%            Maximal formula depth :    9 (   4 average)
%            Number of connectives :   63 (   3 ~  ;   4  |;  28  &)
%                                         (   4 <=>;  24 =>;   0 <=)
%                                         (   0 <~>;   0 ~|;   0 ~&)
%            Number of predicates  :    8 (   0 propositional; 1-2 arity)
%            Number of functors    :    5 (   3 constant; 0-2 arity)
%            Number of variables   :   77 (   0 singleton;  77 !;   0 ?)
%            Maximal term depth    :    2 (   1 average)

% Comments : See MGT042+1.p for the mnemonic names.
%--------------------------------------------------------------------------
%----Include equality axioms
include('Axioms/EQU001+0.ax').
%----Include inequality axioms
include('Axioms/MGT001+0.ax').
include('Axioms/MGT001+0.eq').
%--------------------------------------------------------------------------
input_formula(age_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(age(A,C),age(B,C)) )   )).

input_formula(age_substitution_2,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(age(C,A),age(C,B)) )   )).

input_formula(hazard_of_mortality_substitution_1,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(hazard_of_mortality(A,C),hazard_of_mortality(B,C)) )   )).

input_formula(hazard_of_mortality_substitution_2,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(hazard_of_mortality(C,A),hazard_of_mortality(C,B)) )   )).

input_formula(has_endowment_substitution_1,axiom,(
    ! [A,B] :
      ( ( equal(A,B)
        & has_endowment(A) )
     => has_endowment(B) )   )).

input_formula(has_immunity_substitution_1,axiom,(
    ! [A,B,C] :
      ( ( equal(A,B)
        & has_immunity(A,C) )
     => has_immunity(B,C) )   )).

input_formula(has_immunity_substitution_2,axiom,(
    ! [A,B,C] :
      ( ( equal(A,B)
        & has_immunity(C,A) )
     => has_immunity(C,B) )   )).

input_formula(organization_substitution_1,axiom,(
    ! [A,B] :
      ( ( equal(A,B)
        & organization(A) )
     => organization(B) )   )).

%----Problem Axioms
%----An endowment provides an immunity that lasts until an
%----organization's age exceeds `eta'.
input_formula(definition_1,axiom,(
    ! [X] : 
      ( has_endowment(X)
    <=> ! [T] : 
          ( organization(X)
          & ( smaller_or_equal(age(X,T),eta)
           => has_immunity(X,T) )
          & ( greater(age(X,T),eta)
           => ~ has_immunity(X,T) ) ) )   )).

%----An organization's hazard of mortality is constant during periods
%----in which it has immunity.
input_formula(assumption_2,axiom,(
    ! [X,T0,T] : 
      ( ( organization(X)
        & has_immunity(X,T0)
        & has_immunity(X,T) )
     => equal(hazard_of_mortality(X,T0),hazard_of_mortality(X,T)) )   )).

%----An organization's hazard of mortality is lower during periods in
%----which it has immunity than in periods in which it does not.
input_formula(assumption_3,axiom,(
    ! [X,T0,T] : 
      ( ( organization(X)
        & has_immunity(X,T0)
        & ~ has_immunity(X,T) )
     => greater(hazard_of_mortality(X,T),hazard_of_mortality(X,T0)) )   )).

%----Problem theorems
%----When (`eta' >= `sigma') in a drifting environment, an endowed
%----organization's hazard of mortality remains constant until age
%----`eta' and then jumps to a higher level in a drifting environment.
%----From D1, A2, A3 (text says D1-2, A1-3, 13-16; also needs D<, D<=, D>=, 
%----MP>str, MP>com, MP>tra).
input_formula(lemma_9,conjecture,(
    ! [X,T0,T1,T2] : 
      ( ( organization(X)
        & has_endowment(X)
        & equal(age(X,T0),zero)
        & smaller_or_equal(age(X,T1),eta)
        & greater(age(X,T2),eta)
        & greater_or_equal(eta,sigma)
        & greater(sigma,zero) )
     => ( greater(hazard_of_mortality(X,T2),hazard_of_mortality(X,T1))
        & equal(hazard_of_mortality(X,T1),hazard_of_mortality(X,T0)) ) )   )).
%--------------------------------------------------------------------------
