%--------------------------------------------------------------------------
% File     : MGT059+1 : TPTP v2.6.0. Released v2.4.0.
% Domain   : Management (Organisation Theory)
% Problem  : Hazard of mortality is constant during periods of immunity
% Version  : [Han98] axioms.
% English  : An organization's hazard of mortality is constant during periods
%            in which it has immunity.

% Refs     : [Kam00] Kamps (2000), Email to G. Sutcliffe
%            [CH00]  Carroll & Hannan (2000), The Demography of Corporation
%            [Han98] Hannan (1998), Rethinking Age Dependence in Organizati
% Source   : [Kam00]
% Names    : ASSUMPTION 2 [Han98]

% Status   : theorem
% Rating   : 0.00 v2.4.0
% Syntax   : Number of formulae    :   28 (   1 unit)
%            Number of atoms       :   91 (  34 equality)
%            Maximal formula depth :   11 (   4 average)
%            Number of connectives :   69 (   6 ~  ;   4  |;  28  &)
%                                         (   3 <=>;  28 =>;   0 <=)
%                                         (   0 <~>;   0 ~|;   0 ~&)
%            Number of predicates  :    9 (   0 propositional; 1-2 arity)
%            Number of functors    :    6 (   5 constant; 0-2 arity)
%            Number of variables   :   74 (   0 singleton;  74 !;   0 ?)
%            Maximal term depth    :    2 (   1 average)

% Comments : See MGT042+1.p for the mnemonic names.
%--------------------------------------------------------------------------
%----Include equality axioms
include('Axioms/EQU001+0.ax').
%----Include inequality axioms
include('Axioms/MGT001+0.ax').
include('Axioms/MGT001+0.eq').
%--------------------------------------------------------------------------
input_formula(hazard_of_mortality_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(hazard_of_mortality(A,C),hazard_of_mortality(B,C)) )   )).

input_formula(hazard_of_mortality_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(hazard_of_mortality(C,A),hazard_of_mortality(C,B)) )   )).

input_formula(has_immunity_substitution_1,axiom,(
    ! [A,B,C] :
      ( ( equal(A,B)
        & has_immunity(A,C) )
     => has_immunity(B,C) )   )).

input_formula(has_immunity_substitution_2,axiom,(
    ! [A,B,C] :
      ( ( equal(A,B)
        & has_immunity(C,A) )
     => has_immunity(C,B) )   )).

input_formula(is_aligned_substitution_1,axiom,(
    ! [A,B,C] :
      ( ( equal(A,B)
        & is_aligned(A,C) )
     => is_aligned(B,C) )   )).

input_formula(is_aligned_substitution_2,axiom,(
    ! [A,B,C] :
      ( ( equal(A,B)
        & is_aligned(C,A) )
     => is_aligned(C,B) )   )).

input_formula(organization_substitution_1,axiom,(
    ! [A,B] :
      ( ( equal(A,B)
        & organization(A) )
     => organization(B) )   )).

input_formula(positional_advantage_substitution_1,axiom,(
    ! [A,B,C] :
      ( ( equal(A,B)
        & positional_advantage(A,C) )
     => positional_advantage(B,C) )   )).

input_formula(positional_advantage_substitution_2,axiom,(
    ! [A,B,C] :
      ( ( equal(A,B)
        & positional_advantage(C,A) )
     => positional_advantage(C,B) )   )).

%----Problem Axioms
%----An organization's immunity. alignment of capability with the
%----current state of the environment and positional advantage jointly 
%----affect the hazard of mortality with the following ordinal scaling:
input_formula(assumption_17,axiom,(
    ! [X,T] : 
      ( organization(X)
     => ( ( has_immunity(X,T)
         => equal(hazard_of_mortality(X,T),very_low) )
        & ( ~ has_immunity(X,T)
         => ( ( ( is_aligned(X,T)
                & positional_advantage(X,T) )
             => equal(hazard_of_mortality(X,T),low) )
            & ( ( ~ is_aligned(X,T)
                & positional_advantage(X,T) )
             => equal(hazard_of_mortality(X,T),mod1) )
            & ( ( is_aligned(X,T)
                & ~ positional_advantage(X,T) )
             => equal(hazard_of_mortality(X,T),mod2) )
            & ( ( ~ is_aligned(X,T)
                & ~ positional_advantage(X,T) )
             => equal(hazard_of_mortality(X,T),high) ) ) ) ) )   )).

%----Problem theorems
%----Text says on p.152 ``These assumptions [A17,A18] have the same effect 
%----  as assumptions 2 and 3 in the formalization used in section III.''
%----This is indeed the case for these assumptions are now derivable. 
%----A2 from A17 (no inequalities needed).
%----
%----An organization's hazard of mortality is constant during periods
%----in which it has immunity.
input_formula(assumption_2,conjecture,(
    ! [X,T0,T] : 
      ( ( organization(X)
        & has_immunity(X,T0)
        & has_immunity(X,T) )
     => equal(hazard_of_mortality(X,T0),hazard_of_mortality(X,T)) )   )).
%--------------------------------------------------------------------------
