%--------------------------------------------------------------------------
% File     : MGT060+1 : TPTP v2.6.0. Released v2.4.0.
% Domain   : Management (Organisation Theory)
% Problem  : Hazard of mortality is lower during periods of immunity
% Version  : [Han98] axioms.
% English  : An organization's hazard of mortality is lower during periods in
%            which it has immunity than in periods in which it does not.

% Refs     : [Kam00] Kamps (2000), Email to G. Sutcliffe
%            [CH00]  Carroll & Hannan (2000), The Demography of Corporation
%            [Han98] Hannan (1998), Rethinking Age Dependence in Organizati
% Source   : [Kam00]
% Names    : ASSUMPTION 3 [Han98]

% Status   : theorem
% Rating   : 0.33 v2.4.0
% Syntax   : Number of formulae    :   33 (   6 unit)
%            Number of atoms       :   96 (  33 equality)
%            Maximal formula depth :   11 (   3 average)
%            Number of connectives :   70 (   7 ~  ;   4  |;  28  &)
%                                         (   3 <=>;  28 =>;   0 <=)
%                                         (   0 <~>;   0 ~|;   0 ~&)
%            Number of predicates  :    9 (   0 propositional; 1-2 arity)
%            Number of functors    :    6 (   5 constant; 0-2 arity)
%            Number of variables   :   74 (   0 singleton;  74 !;   0 ?)
%            Maximal term depth    :    2 (   1 average)

% Comments : See MGT042+1.p for the mnemonic names.
%--------------------------------------------------------------------------
%----Include equality axioms
include('Axioms/EQU001+0.ax').
%----Include inequality axioms
include('Axioms/MGT001+0.ax').
include('Axioms/MGT001+0.eq').
%--------------------------------------------------------------------------
input_formula(hazard_of_mortality_substitution_1,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(hazard_of_mortality(A,C),hazard_of_mortality(B,C)) )   )).

input_formula(hazard_of_mortality_substitution_2,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(hazard_of_mortality(C,A),hazard_of_mortality(C,B)) )   )).

input_formula(has_immunity_substitution_1,axiom,(
    ! [A,B,C] :
      ( ( equal(A,B)
        & has_immunity(A,C) )
     => has_immunity(B,C) )   )).

input_formula(has_immunity_substitution_2,axiom,(
    ! [A,B,C] :
      ( ( equal(A,B)
        & has_immunity(C,A) )
     => has_immunity(C,B) )   )).

input_formula(is_aligned_substitution_1,axiom,(
    ! [A,B,C] :
      ( ( equal(A,B)
        & is_aligned(A,C) )
     => is_aligned(B,C) )   )).

input_formula(is_aligned_substitution_2,axiom,(
    ! [A,B,C] :
      ( ( equal(A,B)
        & is_aligned(C,A) )
     => is_aligned(C,B) )   )).

input_formula(organization_substitution_1,axiom,(
    ! [A,B] :
      ( ( equal(A,B)
        & organization(A) )
     => organization(B) )   )).

input_formula(positional_advantage_substitution_1,axiom,(
    ! [A,B,C] :
      ( ( equal(A,B)
        & positional_advantage(A,C) )
     => positional_advantage(B,C) )   )).

input_formula(positional_advantage_substitution_2,axiom,(
    ! [A,B,C] :
      ( ( equal(A,B)
        & positional_advantage(C,A) )
     => positional_advantage(C,B) )   )).

%----Problem Axioms
%----An organization's immunity. alignment of capability with the
%----current state of the environment and positional advantage jointly 
%----affect the hazard of mortality with the following ordinal scaling:
input_formula(assumption_17,axiom,(
    ! [X,T] : 
      ( organization(X)
     => ( ( has_immunity(X,T)
         => equal(hazard_of_mortality(X,T),very_low) )
        & ( ~ has_immunity(X,T)
         => ( ( ( is_aligned(X,T)
                & positional_advantage(X,T) )
             => equal(hazard_of_mortality(X,T),low) )
            & ( ( ~ is_aligned(X,T)
                & positional_advantage(X,T) )
             => equal(hazard_of_mortality(X,T),mod1) )
            & ( ( is_aligned(X,T)
                & ~ positional_advantage(X,T) )
             => equal(hazard_of_mortality(X,T),mod2) )
            & ( ( ~ is_aligned(X,T)
                & ~ positional_advantage(X,T) )
             => equal(hazard_of_mortality(X,T),high) ) ) ) ) )   )).

%----The levels of hazard of mortality are ordered:
%----
%----Split over 5 separate formulas because TPTP gives an error on top 
%----level occurrences of `&'.
input_formula(assumption_18a,axiom,(
    greater(high,mod1)   )).

input_formula(assumption_18b,axiom,(
    greater(mod1,low)   )).

input_formula(assumption_18c,axiom,(
    greater(low,very_low)   )).

input_formula(assumption_18d,axiom,(
    greater(high,mod2)   )).

input_formula(assumption_18e,axiom,(
    greater(mod2,low)   )).

%----Problem theorems
%----Text says on p.152 ``These assumptions [A17,A18] have the same effect 
%----  as assumptions 2 and 3 in the formalization used in section III.''
%----This is indeed the case for these assumptions are now derivable. 
%----A3 from A17, A18a,b,c,e (also needs D<, MP>str, MP>com, MP>tra).
%----
%----An organization's hazard of mortality is lower during periods in
%----which it has immunity than in periods in which it does not.
input_formula(assumption_3,conjecture,(
    ! [X,T0,T] : 
      ( ( organization(X)
        & has_immunity(X,T0)
        & ~ has_immunity(X,T) )
     => greater(hazard_of_mortality(X,T),hazard_of_mortality(X,T0)) )   )).
%--------------------------------------------------------------------------
