%--------------------------------------------------------------------------
% File     : MGT062+1 : TPTP v2.6.0. Released v2.4.0.
% Domain   : Management (Organisation Theory)
% Problem  : Condictions for decreasing hazard of mortality
% Version  : [Han98] axioms.
% English  : If environmental drift destroys alignment exactly when advantage 
%            can be gained from occupancy of a robust position, then the 
%            hazard of mortality for an unendowed organization with a robust 
%            position decreases with age.

% Refs     : [Kam00] Kamps (2000), Email to G. Sutcliffe
%            [CH00]  Carroll & Hannan (2000), The Demography of Corporation
%            [Han98] Hannan (1998), Rethinking Age Dependence in Organizati
% Source   : [Kam00]
% Names    : THEOREM 8 [Han98]

% Status   : theorem
% Rating   : 0.33 v2.4.0
% Syntax   : Number of formulae    :   41 (   2 unit)
%            Number of atoms       :  137 (  47 equality)
%            Maximal formula depth :   11 (   4 average)
%            Number of connectives :  107 (  11 ~  ;   4  |;  45  &)
%                                         (   7 <=>;  40 =>;   0 <=)
%                                         (   0 <~>;   0 ~|;   0 ~&)
%            Number of predicates  :   12 (   0 propositional; 1-3 arity)
%            Number of functors    :   10 (   8 constant; 0-2 arity)
%            Number of variables   :  109 (   0 singleton; 109 !;   0 ?)
%            Maximal term depth    :    2 (   1 average)

% Comments : See MGT042+1.p for the mnemonic names.
%--------------------------------------------------------------------------
%----Include equality axioms
include('Axioms/EQU001+0.ax').
%----Include inequality axioms
include('Axioms/MGT001+0.ax').
include('Axioms/MGT001+0.eq').
%--------------------------------------------------------------------------
input_formula(age_substitution_1,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(age(A,C),age(B,C)) )   )).
        
input_formula(age_substitution_2,axiom,(
    ! [A,B,C] : 
      ( equal(A,B)
     => equal(age(C,A),age(C,B)) )   )).

input_formula(hazard_of_mortality_substitution_1,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(hazard_of_mortality(A,C),hazard_of_mortality(B,C)) )   )).

input_formula(hazard_of_mortality_substitution_2,axiom,(
    ! [A,B,C] :
      ( equal(A,B)
     => equal(hazard_of_mortality(C,A),hazard_of_mortality(C,B)) )   )).

input_formula(dissimilar_substitution_1,axiom,(
    ! [A,B,C,D] :
      ( ( equal(A,B)
        & dissimilar(A,C,D) )
     => dissimilar(B,C,D) )   )).

input_formula(dissimilar_substitution_2,axiom,(
    ! [A,B,C,D] :
      ( ( equal(A,B)
        & dissimilar(C,A,D) )
     => dissimilar(C,B,D) )   )).

input_formula(dissimilar_substitution_3,axiom,(
    ! [A,B,C,D] :
      ( ( equal(A,B)
        & dissimilar(C,D,A) )
     => dissimilar(C,D,B) )   )).

input_formula(has_endowment_substitution_1,axiom,(
    ! [A,B] :
      ( ( equal(A,B)
        & has_endowment(A) )
     => has_endowment(B) )   )).

input_formula(has_immunity_substitution_1,axiom,(
    ! [A,B,C] :
      ( ( equal(A,B)
        & has_immunity(A,C) )
     => has_immunity(B,C) )   )).

input_formula(has_immunity_substitution_2,axiom,(
    ! [A,B,C] :
      ( ( equal(A,B)
        & has_immunity(C,A) )
     => has_immunity(C,B) )   )).

input_formula(is_aligned_substitution_1,axiom,(
    ! [A,B,C] :
      ( ( equal(A,B)
        & is_aligned(A,C) )
     => is_aligned(B,C) )   )).

input_formula(is_aligned_substitution_2,axiom,(
    ! [A,B,C] :
      ( ( equal(A,B)
        & is_aligned(C,A) )
     => is_aligned(C,B) )   )).

input_formula(organization_substitution_1,axiom,(
    ! [A,B] :
      ( ( equal(A,B)
        & organization(A) )
     => organization(B) )   )).

input_formula(positional_advantage_substitution_1,axiom,(
    ! [A,B,C] :
      ( ( equal(A,B)
        & positional_advantage(A,C) )
     => positional_advantage(B,C) )   )).

input_formula(positional_advantage_substitution_2,axiom,(
    ! [A,B,C] :
      ( ( equal(A,B)
        & positional_advantage(C,A) )
     => positional_advantage(C,B) )   )).

input_formula(robust_position_substitution_1,axiom,(
    ! [A,B] :
      ( ( equal(A,B)
        & robust_position(A) )
     => robust_position(B) )   )).

%----Problem Axioms
%----An unendowed organization never possesses immunity.
input_formula(assumption_1,axiom,(
    ! [X,T] : 
      ( ( organization(X)
        & ~ has_endowment(X) )
     => ~ has_immunity(X,T) )   )).

%----Two states of the environment are dissimilar for an organization
%----if and only if the organization cannot be aligned to both.
%----
%----Added quantification over X.
input_formula(definition_2,axiom,(
    ! [X,T0,T] : 
      ( dissimilar(X,T0,T)
    <=> ( organization(X)
        & ~ ( is_aligned(X,T0)
          <=> is_aligned(X,T) ) ) )   )).

%----An organization is aligned with the state of the environment at
%----its time of founding. 
input_formula(assumption_13,axiom,(
    ! [X,T] : 
      ( ( organization(X)
        & equal(age(X,T),zero) )
     => is_aligned(X,T) )   )).

%----Environmental drift: the environments at times separated by more
%----than `sigma' are dissimilar. 
input_formula(assumption_15,axiom,(
    ! [X,T0,T] : 
      ( ( organization(X)
        & equal(age(X,T0),zero) )
     => ( greater(age(X,T),sigma)
      <=> dissimilar(X,T0,T) ) )   )).

%----An organization's position is robust if and only if it provides
%----positional advantage only after age `tau'.
%----
%----Text says fragile_position(X) instead of robust_position(X).
%----Interchanged ~ positional_advantage(X,T) and positional_advantage(X,T).
input_formula(definition_4,axiom,(
    ! [X] : 
      ( robust_position(X)
    <=> ! [T] : 
          ( ( smaller_or_equal(age(X,T),tau)
           => ~ positional_advantage(X,T) )
          & ( greater(age(X,T),tau)
           => positional_advantage(X,T) ) ) )   )).

%----An organization's immunity. alignment of capability with the
%----current state of the environment and positional advantage jointly 
%----affect the hazard of mortality with the following ordinal scaling:
input_formula(assumption_17,axiom,(
    ! [X,T] : 
      ( organization(X)
     => ( ( has_immunity(X,T)
         => equal(hazard_of_mortality(X,T),very_low) )
        & ( ~ has_immunity(X,T)
         => ( ( ( is_aligned(X,T)
                & positional_advantage(X,T) )
             => equal(hazard_of_mortality(X,T),low) )
            & ( ( ~ is_aligned(X,T)
                & positional_advantage(X,T) )
             => equal(hazard_of_mortality(X,T),mod1) )
            & ( ( is_aligned(X,T)
                & ~ positional_advantage(X,T) )
             => equal(hazard_of_mortality(X,T),mod2) )
            & ( ( ~ is_aligned(X,T)
                & ~ positional_advantage(X,T) )
             => equal(hazard_of_mortality(X,T),high) ) ) ) ) )   )).

%----Position dominates alignment:
input_formula(assumption_19,axiom,(
    greater(mod2,mod1)   )).

%----Problem theorems
%----Robust position without endowment when (`sigma' = `tau'): If
%----environmental drift destroys alignment exactly when advantage can 
%----be gained from occupancy of a robust position (`sigma' = `tau'), then 
%----the hazard of mortality for an unendowed organization with a
%----robust position decreases with age.
%----From D2, D4 and A1, A13, A15, A17 (text says D1,2 and A1,2,13-15,17-19;
%----also needs D<, D<=).
%----
%----Added (`sigma' = `tau') in antecedent
%----and (hazard_of_mortality(X,T1) = hazard_of_mortality(X,T0)).
input_formula(theorem_8,conjecture,(
    ! [X,T0,T1,T2] : 
      ( ( organization(X)
        & robust_position(X)
        & ~ has_endowment(X)
        & equal(age(X,T0),zero)
        & greater(sigma,zero)
        & greater(tau,zero)
        & equal(sigma,tau)
        & smaller_or_equal(age(X,T1),sigma)
        & greater(age(X,T2),sigma) )
     => ( smaller(hazard_of_mortality(X,T2),hazard_of_mortality(X,T1))
        & equal(hazard_of_mortality(X,T1),hazard_of_mortality(X,T0)) ) )   )).
%--------------------------------------------------------------------------
