%--------------------------------------------------------------------------
% File     : RNG001-5 : TPTP v2.6.0. Released v1.0.0.
% Domain   : Ring Theory
% Problem  : X.additive_identity = additive_identity for any X
% Version  : [Wos65] axioms : Reduced > Incomplete.
% English  : 

% Refs     : [Wos65] Wos (1965), Unpublished Note
%          : [FL+74] Fleisig et al. (1974), An Implementation of the Model 
%          : [WM76]  Wilson & Minker (1976), Resolution, Refinements, and S
% Source   : [SPRFN]
% Names    : Problem 21 [Wos65]
%          : wos21 [WM76]

% Status   : unsatisfiable
% Rating   : 0.25 v2.6.0, 0.43 v2.5.0, 0.29 v2.4.0, 0.29 v2.3.0, 0.57 v2.2.1, 0.67 v2.1.0, 0.57 v2.0.0
% Syntax   : Number of clauses    :   30 (   0 non-Horn;   8 unit;  21 RR)
%            Number of literals   :   81 (   0 equality)
%            Maximal clause size  :    5 (   2 average)
%            Number of predicates :    3 (   0 propositional; 2-3 arity)
%            Number of functors   :    5 (   2 constant; 0-2 arity)
%            Number of variables  :  109 (   0 singleton)
%            Maximal term depth   :    2 (   1 average)

% Comments : Omits two equality subsitution axioms.
%          : These are the same axioms as in [MOW76].
%          : I guess this is Example 6c in [FL+74].
%--------------------------------------------------------------------------
%----Don't include equality axioms, because it's incomplete
%include('Axioms/EQU001-0.ax').
%----Include ring theory axioms 
%include('Axioms/RNG001-0.ax').
%--------------------------------------------------------------------------
input_clause(reflexivity,axiom,
    [++equalish(X,X)]).

input_clause(symmetry,axiom,
    [--equalish(X,Y),
     ++equalish(Y,X)]).

input_clause(transitivity,axiom,
    [--equalish(X,Y),
     --equalish(Y,Z),
     ++equalish(X,Z)]).

input_clause(additive_identity1,axiom,
    [++sum(additive_identity,X,X)]).

input_clause(additive_identity2,axiom,
    [++sum(X,additive_identity,X)]).

input_clause(closure_of_multiplication,axiom,
    [++product(X,Y,multiply(X,Y))]).

input_clause(closure_of_addition,axiom,
    [++sum(X,Y,add(X,Y))]).

input_clause(left_inverse,axiom,
    [++sum(additive_inverse(X),X,additive_identity)]).

input_clause(right_inverse,axiom,
    [++sum(X,additive_inverse(X),additive_identity)]).

input_clause(associativity_of_addition1,axiom,
    [--sum(X,Y,U),
     --sum(Y,Z,V),
     --sum(U,Z,W),
     ++sum(X,V,W)]).

input_clause(associativity_of_addition2,axiom,
    [--sum(X,Y,U),
     --sum(Y,Z,V),
     --sum(X,V,W),
     ++sum(U,Z,W)]).

input_clause(commutativity_of_addition,axiom,
    [--sum(X,Y,Z),
     ++sum(Y,X,Z)]).

input_clause(associativity_of_multiplication1,axiom,
    [--product(X,Y,U),
     --product(Y,Z,V),
     --product(U,Z,W),
     ++product(X,V,W)]).

input_clause(associativity_of_multiplication2,axiom,
    [--product(X,Y,U),
     --product(Y,Z,V),
     --product(X,V,W),
     ++product(U,Z,W)]).

input_clause(distributivity1,axiom,
    [--product(X,Y,V1),
     --product(X,Z,V2),
     --sum(Y,Z,V3),
     --product(X,V3,V4),
     ++sum(V1,V2,V4)]).

input_clause(distributivity2,axiom,
    [--product(X,Y,V1),
     --product(X,Z,V2),
     --sum(Y,Z,V3),
     --sum(V1,V2,V4),
     ++product(X,V3,V4)]).

input_clause(distributivity3,axiom,
    [--product(Y,X,V1),
     --product(Z,X,V2),
     --sum(Y,Z,V3),
     --product(V3,X,V4),
     ++sum(V1,V2,V4)]).

input_clause(distributivity4,axiom,
    [--product(Y,X,V1),
     --product(Z,X,V2),
     --sum(Y,Z,V3),
     --sum(V1,V2,V4),
     ++product(V3,X,V4)]).

%-----Equality axioms for operators 
input_clause(addition_is_well_defined,axiom,
    [--sum(X,Y,U),
     --sum(X,Y,V),
     ++equalish(U,V)]).

input_clause(multiplication_is_well_defined,axiom,
    [--product(X,Y,U),
     --product(X,Y,V),
     ++equalish(U,V)]).

%----Equality axioms for additive operator 
input_clause(additive_inverse_substitution,axiom,
    [--equalish(X,Y),
     ++equalish(additive_inverse(X),additive_inverse(Y))]).

input_clause(add_substitution1,axiom,
    [--equalish(X,Y),
     ++equalish(add(X,W),add(Y,W))]).

%----This axiom omited in this version 
%input_clause(add_substitution2,axiom,
%    [--equalish(X,Y),
%     ++equalish(add(W,X),add(W,Y))]).

input_clause(sum_substitution1,axiom,
    [--equalish(X,Y),
     --sum(X,W,Z),
     ++sum(Y,W,Z)]).

input_clause(sum_substitution2,axiom,
    [--equalish(X,Y),
     --sum(W,X,Z),
     ++sum(W,Y,Z)]).

input_clause(sum_substitution3,axiom,
    [--equalish(X,Y),
     --sum(W,Z,X),
     ++sum(W,Z,Y)]).

%----Equality axioms for multiplicative operator 
input_clause(multiply_substitution1,axiom,
    [--equalish(X,Y),
     ++equalish(multiply(X,W),multiply(Y,W))]).

%----This axiom omited in this version 
%input_clause(multiply_substitution2,axiom,
%    [--equalish(X,Y),
%     ++equalish(multiply(W,X),multiply(W,Y))]).

input_clause(product_substitution1,axiom,
    [--equalish(X,Y),
     --product(X,W,Z),
     ++product(Y,W,Z)]).

input_clause(product_substitution2,axiom,
    [--equalish(X,Y),
     --product(W,X,Z),
     ++product(W,Y,Z)]).

input_clause(product_substitution3,axiom,
    [--equalish(X,Y),
     --product(W,Z,X),
     ++product(W,Z,Y)]).

input_clause(prove_multiplicative_identity_axiom,conjecture,
    [--product(a,additive_identity,additive_identity)]).
%--------------------------------------------------------------------------
