%--------------------------------------------------------------------------
% File     : RNG010-2 : TPTP v2.6.0. Bugfixed v1.2.1.
% Domain   : Ring Theory (Alternative)
% Problem  : Skew symmetry of the auxilliary function
% Version  : [AH90] (equality) axioms : Augmented.
%            Theorem formulation : In terms of the associator
% English  : The left and right Moufang identities imply the skew symmetry 
%            of s(W,X,Y,Z) = (W*X,Y,Z) - X*(W,Y,Z) - (X,Y,Z)*W.
%            Recall that skew symmetry means that the function sign 
%            changes when any two arguments are swapped. This problem 
%            proves the case for swapping the first two arguments.

% Refs     : [AH90]  Anantharaman & Hsiang (1990), Automated Proofs of the 
% Source   : [AH90]
% Names    : PROOF VI [AH90]

% Status   : unsatisfiable
% Rating   : 0.00 v2.0.0
% Syntax   : Number of clauses    :   35 (   0 non-Horn;  23 unit;  10 RR)
%            Number of literals   :   48 (  48 equality)
%            Maximal clause size  :    3 (   1 average)
%            Number of predicates :    1 (   0 propositional; 2-2 arity)
%            Number of functors   :    8 (   4 constant; 0-3 arity)
%            Number of variables  :   81 (   2 singleton)
%            Maximal term depth   :    5 (   1 average)

% Comments : This how the problem appears in [AH90].
% Bugfixes : v1.2.1 - Clause left_moufang fixed.
%--------------------------------------------------------------------------
%----Include equality axioms 
include('Axioms/EQU001-0.ax').
%----Include Ring theory (equality) axioms 
include('Axioms/RNG004-0.ax').
%--------------------------------------------------------------------------
%----Associator 
input_clause(associator,axiom,
    [++equal(associator(X,Y,Z),add(multiply(multiply(X,Y),Z),
additive_inverse(multiply(X,multiply(Y,Z)))))]).

input_clause(associator_substitution1,axiom,
    [--equal(L,M),
     ++equal(associator(L,N,O),associator(M,N,O))]).

input_clause(associator_substitution2,axiom,
    [--equal(P,Q),
     ++equal(associator(R,P,S),associator(R,Q,S))]).

input_clause(associator_substitution3,axiom,
    [--equal(T,U),
     ++equal(associator(V,W,T),associator(V,W,U))]).

%----The next three clauses are previously proved lemmas 
input_clause(middle_law,axiom,
    [--equal(multiply(multiply(Y,X),Y),multiply(Y,multiply(X,Y)))]).

input_clause(associator_skew_symmetry1,axiom,
    [--equal(associator(Y,X,Z),additive_inverse(associator(X,Y,Z)))]).

input_clause(associator_skew_symmetry2,axiom,
    [--equal(associator(Z,Y,X),additive_inverse(associator(X,Y,Z)))]).

input_clause(right_moufang,hypothesis,
    [++equal(multiply(Z,multiply(X,multiply(Y,X))),
multiply(multiply(multiply(Z,X),Y),X))]).

input_clause(left_moufang,hypothesis,
    [++equal(multiply(multiply(X,multiply(Y,X)),Z),
multiply(X,multiply(Y,multiply(X,Z))))]).

input_clause(prove_skew_symmetry,conjecture,
    [--equal(associator(multiply(cx,cx),cy,cz),
add(multiply(associator(cx,cy,cz),cx),multiply(cx,associator(cx,cy,cz))))]).
%--------------------------------------------------------------------------
